@@ -9,7 +9,7 @@ import logging
 logging.basicConfig(level=logging.DEBUG)
 import sys
 
-from pyqode.qt import QtWidgets
+from qtpy import QtWidgets
 from pyqode.core.api import CodeEdit
 from pyqode.core.backend import server
 from pyqode.core.modes import CaretLineHighlighterMode
